# gntplib

gntplib is a Growl Notification Transport Protocol ([GNTP](http://www.growlforwindows.com/gfw/help/gntp.aspx)) client library in Python.

gntplib is tested on Python 3.+, [Growl](http://growl.info/) 1.3.3 and [Growl for Windows](http://www.growlforwindows.com/) 2.0.9.

[![PyPI version](https://img.shields.io/pypi/v/gntplib.svg?color=blue&logo=pypi)](https://pypi.org/project/gntplib/)
[![Python Versions](https://img.shields.io/pypi/pyversions/gntplib.svg?logo=python)](https://pypi.org/project/gntplib/)
[![License](https://img.shields.io/github/license/cumulus13/gntplib?color=green)](https://github.com/cumulus13/gntplib/blob/master/LICENSE)
[![Downloads](https://static.pepy.tech/badge/gntplib)](https://pepy.tech/project/gntplib)
[![Documentation](https://img.shields.io/badge/docs-latest-brightgreen.svg)](https://gntplib.readthedocs.io/)

<p align="center">
  <img src="https://raw.githubusercontent.com/cumulus13/gntplib/master/docs/_static/logo.png" alt="Logo" width="320">
</p>


## Installation

Simply use pip:

```bash
$ pip install gntplib
```

There are the following **optional** prerequisites:

* `pycryptodome` - to use `gntplib.ciphers` module for message encryption
* `tornado` - to use `gntplib.async` module for asynchronous processing

## Documentation

http://gntplib.readthedocs.org/en/latest/

## License
gntplib is licensed under the MIT License. See the [LICENSE](LICENSE) file for details.

## Author
[Hadi Cahyadi](mailto:cumulus13@gmail.com)
    
[![Buy Me a Coffee](https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png)](https://www.buymeacoffee.com/cumulus13)

[![Donate via Ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/cumulus13)
 
[Support me on Patreon](https://www.patreon.com/cumulus13)
